function AndrzejakChaos2021ExampleR2(Example)
% This source code allows you to reproduce the simulations presented in
%
% Andrzejak RG
% Chimeras confined in fractal boundaries in the complex plane
% Chaos 31, 053104 (2021); doi: 10.1063/5.0049631
%
% Please give a reference to this manuscript if you use this source code in
% your publications.
%
% This is the second release of this source code. The content of this
% script was not changed. Only the script function 
% AndrzejakChaos2021CoreIterationR2.m included in the package was
% corrected.
%
% Prior to using the code, please see the remarks starting in line 25.
%
% Input
% 1: Low-resolution, low-nmax estimation of global view, using an odd 
%    number of pixels such that the real axis is included in the middle.
% 2: Low-resolution, low-nmax estimation of Figure 3c.
% 3: Low-resolution, low-nmax estimation of Figure 3f.
%
%
% Before publishing the source code, we have simplified it and reduced
% it to the essentials to allow for a better understanding. We furthermore
% matched variable names in the source code to those in the manuscript. We
% are confident that, also with these simplifications and changes, the
% source code contains no bugs. However, if you encounter problems or bugs,
% please contact us.
%
% The source is in part hard-coded for the case used in the manuscript, i.e.
% two populations of two maps each. Most of the code can be trivially
% extended to more maps. Only the part in which the different states of
% synchronization are detected would require a more elaborated adaptation.
%
% When creating your own examples, keep in mind the following:
% Using high values of RePix and ImPix will lead to a high resolution at
% the cost of high computation times.
% Using high values of nmax will lead to a high accuracy at the cost of 
% high computation times. Using too low values can lead to
% misclassifications of synchronization states and periods.
%
% The computation can take very long time. The results of the manuscript
% were achieved using distributed computing on a cluster of 300 CPUs. 
% For this release we added a stopping criterion to speed up the
% computation. If the variable 'exactperiodtest' is set to 1, the iteration 
% is stopped if the periodicity is exact (and not only up to epsnum).
% WARNING: THIS CRITERION WAS NOT USED IN OUR MANUSCRIPT. WE 
% ADDED IT FOR THIS SOURCE CODE RELEASE. TO THE BEST OF OUR 
% UNDERSTANDING IT WORKS FINE. NONETHELESS, IF YOU WANT TO USE 
% IT, YOU SHOULD TEST ITS CORRECTNESS.


switch Example
    case 1
        ReMin = -2;
        ReMax = 0.6;
        RePix = 1001;
        ImMin = -1.3;
        ImMax = 1.3;
        ImPix = 1001;
        nmax = 100000;
        Cw = 0.01;
        Ca = 0.0025;
        epsnum = 1e-13;
        exactperiodtest = 0;
        ndiag = 1000;
        HiResndiv=1;
        maxm = 200;
        verbose = 1;
        AndrzejakChaos2021MainR2(ReMin,ReMax,RePix,ImMin,ImMax,ImPix,nmax,Cw,Ca,epsnum,exactperiodtest,ndiag,HiResndiv,maxm,verbose)
    
    case 2
        ReMin = -0.525;
        ReMax = -0.475;
        RePix = 60;
        ImMin = 0.525;
        ImMax = 0.575;
        ImPix = 60;
        nmax = 10000;
        Cw = 0.01;
        Ca = 0.0025;
        epsnum = 1e-13;
        exactperiodtest = 1;
        ndiag = 1000;
        HiResndiv=1;
        maxm = 200;
        verbose = 1;
        AndrzejakChaos2021MainR2(ReMin,ReMax,RePix,ImMin,ImMax,ImPix,nmax,Cw,Ca,epsnum,exactperiodtest,ndiag,HiResndiv,maxm,verbose)
        
    case 3
        ReMin = -0.508384;
        ReMax = -0.508334;
        RePix = 200;
        ImMin = 0.545494;
        ImMax = 0.545544;
        ImPix = 200;
        nmax = 5000;
        Cw = 0.01;
        Ca = 0.0025;
        epsnum = 1e-13;
        exactperiodtest = 1;
        ndiag = 100;
        HiResndiv=1;
        maxm = 200;
        verbose = 1;
        AndrzejakChaos2021MainR2(ReMin,ReMax,RePix,ImMin,ImMax,ImPix,nmax,Cw,Ca,epsnum,exactperiodtest,ndiag,HiResndiv,maxm,verbose)                
    case 4
        ReMin = -2;
        ReMax = 0.6;
        RePix = 101;
        ImMin = -1.3;
        ImMax = 0;
        ImPix = 51;
        nmax = 200;
        Cw = 0.25;
        Ca = 0.25;
        epsnum = 1e-13;
        exactperiodtest = 1;
        ndiag = 1000;
        HiResndiv=1;
        maxm = 200;
        verbose = 1;
        AndrzejakChaos2021MainR2(ReMin,ReMax,RePix,ImMin,ImMax,ImPix,nmax,Cw,Ca,epsnum,exactperiodtest,ndiag,HiResndiv,maxm,verbose)
    case 5
        ReMin = -2;
        ReMax = 0.6;
        RePix = 101;
        ImMin = -1.3;
        ImMax = 0;
        ImPix = 51;
        nmax = 10000;
        Cw = 0.35;
        Ca = 0.35;
        epsnum = 1e-13;
        exactperiodtest = 0;
        ndiag = 1000;
        HiResndiv=1;
        maxm = 200;
        verbose = 1;
        AndrzejakChaos2021MainR2(ReMin,ReMax,RePix,ImMin,ImMax,ImPix,nmax,Cw,Ca,epsnum,exactperiodtest,ndiag,HiResndiv,maxm,verbose)
    case 6
        ReMin = -2;
        ReMax = 0.6;
        RePix = 101;
        ImMin = -1.3;
        ImMax = 0;
        ImPix = 51;
        nmax = 10000;
        Cw = 0.439038;
        Ca = Cw*0.25;
        epsnum = 1e-13;
        exactperiodtest = 0;
        ndiag = 1000;
        HiResndiv=1;
        maxm = 200;
        verbose = 1;
        AndrzejakChaos2021MainR2(ReMin,ReMax,RePix,ImMin,ImMax,ImPix,nmax,Cw,Ca,epsnum,exactperiodtest,ndiag,HiResndiv,maxm,verbose)
    case 7
        ReMin = -2;
        ReMax = 0.6;
        RePix = 101;
        ImMin = -1.3;
        ImMax = 0;
        ImPix = 51;
        nmax = 10000;
        Cw = 0.439038;
        Ca = Cw*0.5;
        epsnum = 1e-13;
        exactperiodtest = 0;
        ndiag = 1000;
        HiResndiv=1;
        maxm = 200;
        verbose = 1;
        AndrzejakChaos2021MainR2(ReMin,ReMax,RePix,ImMin,ImMax,ImPix,nmax,Cw,Ca,epsnum,exactperiodtest,ndiag,HiResndiv,maxm,verbose)

   case 8
        ReMin = -2;
        ReMax = 0.6;
        RePix = 101;
        ImMin = -1.3;
        ImMax = 0;
        ImPix = 51;
        nmax = 10000;
        Cw = 0.04;
        Ca = Cw*0.25;
        epsnum = 1e-13;
        exactperiodtest = 0;
        ndiag = 1000;
        HiResndiv=1;
        maxm = 200;
        verbose = 1;
        AndrzejakChaos2021MainR2(ReMin,ReMax,RePix,ImMin,ImMax,ImPix,nmax,Cw,Ca,epsnum,exactperiodtest,ndiag,HiResndiv,maxm,verbose)
    


end